@@ -11,14 +11,19 @@ class IContentIcon(Interface):
 
     height = Attribute("Returns the height of the icon (required).")
 
-    url = Attribute("The absolute url of the icon. This should be "
-                    "None if no icon should be rendered.")
+    url = Attribute(
+        "The absolute url of the icon. This should be "
+        "None if no icon should be rendered."
+    )
 
-    description = Attribute("The description used for the alt attribute. "
-                            "Should be at least an empty string.")
+    description = Attribute(
+        "The description used for the alt attribute. "
+        "Should be at least an empty string."
+    )
 
-    title = Attribute("The content of the title attribute. Should be None "
-                      "if the title is empty.")
+    title = Attribute(
+        "The content of the title attribute. Should be None " "if the title is empty."
+    )
 
     def html_tag():
         """Return a HTML string that is the tag for rendering this icon.
